summaryrefslogtreecommitdiff
path: root/src/include/taler_error_codes.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/include/taler_error_codes.h')
-rw-r--r--src/include/taler_error_codes.h11
1 files changed, 10 insertions, 1 deletions
diff --git a/src/include/taler_error_codes.h b/src/include/taler_error_codes.h
index d1727c7d4..56c02264b 100644
--- a/src/include/taler_error_codes.h
+++ b/src/include/taler_error_codes.h
@@ -1251,7 +1251,8 @@ enum TALER_ErrorCode
/**
* The exchange gave conflicting information about a coin which has
* been wire transferred.
* The response is provided with HTTP status code MHD_HTTP_INTERNAL_SERVER_ERROR.
*/
TALER_EC_TRACK_TRANSFER_CONFLICTING_REPORTS = 2408,
@@ -1261,6 +1262,14 @@ enum TALER_ErrorCode
TALER_EC_TRACK_TRANSFER_JSON_RESPONSE_ERROR = 2409,
/**
+ * The exchange charged a different wire fee than what it
+ * originally advertised, and it is higher. The response
+ * is provied with an HTTP status of
+ * MHD_HTTP_INTERNAL_SERVER_ERROR (FIXME: bad choice!).
+ */
+ TALER_EC_TRACK_TRANSFER_JSON_BAD_WIRE_FEE = 2410,
+
+ /**
* The hash provided in the request of /map/in does not match
* the contract sent alongside in the same request.
*/
@@ -1251,7 +1251,8 @@ enum TALER_ErrorCode
* The exchange gave conflicting information about a coin which has
* been wire transferred.
- * The response is provided with HTTP status code MHD_HTTP_INTERNAL_SERVER_ERROR.
+ * The response is provided with HTTP status code
+ * MHD_HTTP_INTERNAL_SERVER_ERROR (FIXME: bad choice!).
*/
TALER_EC_TRACK_TRANSFER_CONFLICTING_REPORTS = 2408,